#include <string_view>
namespace divine::str::dios {
extern const std::string_view libc_regex_tre_mem_c( 
"/*\x0a"
"  tre-mem.c - TRE memory allocator\x0a"
"\x0a"
"  This software is released under a BSD-style license.\x0a"
"  See the file LICENSE for details and copyright.\x0a"
"\x0a"
"*/\x0a"
"\x0a"
"/*\x0a"
"  This memory allocator is for allocating small memory blocks efficiently\x0a"
"  in terms of memory overhead and execution speed.  The allocated blocks\x0a"
"  cannot be freed individually, only all at once.  There can be multiple\x0a"
"  allocators, though.\x0a"
"*/\x0a"
"\x0a"
"#ifdef HAVE_CONFIG_H\x0a"
"#include <config.h>\x0a"
"#endif /* HAVE_CONFIG_H */\x0a"
"#include <stdlib.h>\x0a"
"#include <string.h>\x0a"
"\x0a"
"#include \x22tre-internal.h\x22\x0a"
"#include \x22tre-mem.h\x22\x0a"
"#include \x22xmalloc.h\x22\x0a"
"\x0a"
"\x0a"
"/* Returns a new memory allocator or NULL if out of memory. */\x0a"
"tre_mem_t\x0a"
"tre_mem_new_impl(int provided, void *provided_block)\x0a"
"{\x0a"
"  tre_mem_t mem;\x0a"
"  if (provided)\x0a"
"    {\x0a"
"      mem = provided_block;\x0a"
"      memset(mem, 0, sizeof(*mem));\x0a"
"    }\x0a"
"  else\x0a"
"    mem = xcalloc(1, sizeof(*mem));\x0a"
"  if (mem == NULL)\x0a"
"    return NULL;\x0a"
"  return mem;\x0a"
"}\x0a"
"\x0a"
"\x0a"
"/* Frees the memory allocator and all memory allocated with it. */\x0a"
"void\x0a"
"tre_mem_destroy(tre_mem_t mem)\x0a"
"{\x0a"
"  tre_list_t *tmp, *l = mem->blocks;\x0a"
"\x0a"
"  while (l \x21= NULL)\x0a"
"    {\x0a"
"      xfree(l->data);\x0a"
"      tmp = l->next;\x0a"
"      xfree(l);\x0a"
"      l = tmp;\x0a"
"    }\x0a"
"  xfree(mem);\x0a"
"}\x0a"
"\x0a"
"\x0a"
"/* Allocates a block of \x60size' bytes from \x60mem'.  Returns a pointer to the\x0a"
"   allocated block or NULL if an underlying malloc() failed. */\x0a"
"void *\x0a"
"tre_mem_alloc_impl(tre_mem_t mem, int provided, void *provided_block,\x0a"
"\x09\x09   int zero, size_t size)\x0a"
"{\x0a"
"  void *ptr;\x0a"
"\x0a"
"  if (mem->failed)\x0a"
"    {\x0a"
"      DPRINT((\x22tre_mem_alloc\x3a oops, called after failure\x3f\x21\x5cn\x22));\x0a"
"      return NULL;\x0a"
"    }\x0a"
"\x0a"
"#ifdef MALLOC_DEBUGGING\x0a"
"  if (\x21provided)\x0a"
"    {\x0a"
"      ptr = xmalloc(1);\x0a"
"      if (ptr == NULL)\x0a"
"\x09{\x0a"
"\x09  DPRINT((\x22tre_mem_alloc\x3a xmalloc forced failure\x5cn\x22));\x0a"
"\x09  mem->failed = 1;\x0a"
"\x09  return NULL;\x0a"
"\x09}\x0a"
"      xfree(ptr);\x0a"
"    }\x0a"
"#endif /* MALLOC_DEBUGGING */\x0a"
"\x0a"
"  if (mem->n < size)\x0a"
"    {\x0a"
"      /* We need more memory than is available in the current block.\x0a"
"\x09 Allocate a new block. */\x0a"
"      tre_list_t *l;\x0a"
"      if (provided)\x0a"
"\x09{\x0a"
"\x09  DPRINT((\x22tre_mem_alloc\x3a using provided block\x5cn\x22));\x0a"
"\x09  if (provided_block == NULL)\x0a"
"\x09    {\x0a"
"\x09      DPRINT((\x22tre_mem_alloc\x3a provided block was NULL\x5cn\x22));\x0a"
"\x09      mem->failed = 1;\x0a"
"\x09      return NULL;\x0a"
"\x09    }\x0a"
"\x09  mem->ptr = provided_block;\x0a"
"\x09  mem->n = TRE_MEM_BLOCK_SIZE;\x0a"
"\x09}\x0a"
"      else\x0a"
"\x09{\x0a"
"\x09  int block_size;\x0a"
"\x09  if (size * 8 > TRE_MEM_BLOCK_SIZE)\x0a"
"\x09    block_size = size * 8;\x0a"
"\x09  else\x0a"
"\x09    block_size = TRE_MEM_BLOCK_SIZE;\x0a"
"\x09  DPRINT((\x22tre_mem_alloc\x3a allocating new \x25""d byte block\x5cn\x22,\x0a"
"\x09\x09  block_size));\x0a"
"\x09  l = xmalloc(sizeof(*l));\x0a"
"\x09  if (l == NULL)\x0a"
"\x09    {\x0a"
"\x09      mem->failed = 1;\x0a"
"\x09      return NULL;\x0a"
"\x09    }\x0a"
"\x09  l->data = xmalloc(block_size);\x0a"
"\x09  if (l->data == NULL)\x0a"
"\x09    {\x0a"
"\x09      xfree(l);\x0a"
"\x09      mem->failed = 1;\x0a"
"\x09      return NULL;\x0a"
"\x09    }\x0a"
"\x09  l->next = NULL;\x0a"
"\x09  if (mem->current \x21= NULL)\x0a"
"\x09    mem->current->next = l;\x0a"
"\x09  if (mem->blocks == NULL)\x0a"
"\x09    mem->blocks = l;\x0a"
"\x09  mem->current = l;\x0a"
"\x09  mem->ptr = l->data;\x0a"
"\x09  mem->n = block_size;\x0a"
"\x09}\x0a"
"    }\x0a"
"\x0a"
"  /* Make sure the next pointer will be aligned. */\x0a"
"  size += ALIGN(mem->ptr + size, long);\x0a"
"\x0a"
"  /* Allocate from current block. */\x0a"
"  ptr = mem->ptr;\x0a"
"  mem->ptr += size;\x0a"
"  mem->n -= size;\x0a"
"\x0a"
"  /* Set to zero if needed. */\x0a"
"  if (zero)\x0a"
"    memset(ptr, 0, size);\x0a"
"\x0a"
"  return ptr;\x0a"
"}\x0a"
"\x0a"
"/* EOF */\x0a"
"", 3186 ); }