#include <string_view>
namespace divine::str::dios {
extern const std::string_view libcxx_src_chrono_cpp( 
"//===------------------------- chrono.cpp ---------------------------------===//\x0a"
"//\x0a"
"// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.\x0a"
"// See https\x3a//llvm.org/LICENSE.txt for license information.\x0a"
"// SPDX-License-Identifier\x3a Apache-2.0 WITH LLVM-exception\x0a"
"//\x0a"
"//===----------------------------------------------------------------------===//\x0a"
"\x0a"
"#include \x22""chrono\x22\x0a"
"#include \x22""cerrno\x22        // errno\x0a"
"#include \x22system_error\x22  // __throw_system_error\x0a"
"#include <time.h>        // clock_gettime, CLOCK_MONOTONIC and CLOCK_REALTIME\x0a"
"#include \x22include/apple_availability.h\x22\x0a"
"\x0a"
"#if \x21""defined(__APPLE__)\x0a"
"#define _LIBCPP_USE_CLOCK_GETTIME\x0a"
"#endif // __APPLE__\x0a"
"\x0a"
"#if defined(_LIBCPP_WIN32API)\x0a"
"#define WIN32_LEAN_AND_MEAN\x0a"
"#define VC_EXTRA_LEAN\x0a"
"#include <windows.h>\x0a"
"#if _WIN32_WINNT >= _WIN32_WINNT_WIN8\x0a"
"#include <winapifamily.h>\x0a"
"#endif\x0a"
"#else\x0a"
"#if \x21""defined(CLOCK_REALTIME) \x7c\x7c \x21""defined(_LIBCPP_USE_CLOCK_GETTIME)\x0a"
"#include <sys/time.h>        // for gettimeofday and timeval\x0a"
"#endif // \x21""defined(CLOCK_REALTIME)\x0a"
"#endif // defined(_LIBCPP_WIN32API)\x0a"
"\x0a"
"#if \x21""defined(_LIBCPP_HAS_NO_MONOTONIC_CLOCK)\x0a"
"#if __APPLE__\x0a"
"#include <mach/mach_time.h>  // mach_absolute_time, mach_timebase_info_data_t\x0a"
"#elif \x21""defined(_LIBCPP_WIN32API) \x26\x26 \x21""defined(CLOCK_MONOTONIC)\x0a"
"#error \x22Monotonic clock not implemented\x22\x0a"
"#endif\x0a"
"#endif\x0a"
"\x0a"
"#if defined(__unix__) \x26\x26  defined(__ELF__) \x26\x26 defined(_LIBCPP_HAS_COMMENT_LIB_PRAGMA)\x0a"
"#pragma comment(lib, \x22rt\x22)\x0a"
"#endif\x0a"
"\x0a"
"_LIBCPP_BEGIN_NAMESPACE_STD\x0a"
"\x0a"
"namespace chrono\x0a"
"{\x0a"
"\x0a"
"// system_clock\x0a"
"\x0a"
"const bool system_clock\x3a\x3ais_steady;\x0a"
"\x0a"
"system_clock\x3a\x3atime_point\x0a"
"system_clock\x3a\x3anow() _NOEXCEPT\x0a"
"{\x0a"
"#if defined(_LIBCPP_WIN32API)\x0a"
"  // FILETIME is in 100ns units\x0a"
"  using filetime_duration =\x0a"
"      _VSTD\x3a\x3a""chrono\x3a\x3a""duration<__int64,\x0a"
"                              _VSTD\x3a\x3aratio_multiply<_VSTD\x3a\x3aratio<100, 1>,\x0a"
"                                                    nanoseconds\x3a\x3aperiod>>;\x0a"
"\x0a"
"  // The Windows epoch is Jan 1 1601, the Unix epoch Jan 1 1970.\x0a"
"  static _LIBCPP_CONSTEXPR const seconds nt_to_unix_epoch{11644473600};\x0a"
"\x0a"
"  FILETIME ft;\x0a"
"#if _WIN32_WINNT >= _WIN32_WINNT_WIN8\x0a"
"#if WINAPI_FAMILY_PARTITION(WINAPI_PARTITION_DESKTOP)\x0a"
"  GetSystemTimePreciseAsFileTime(\x26""ft);\x0a"
"#else\x0a"
"  GetSystemTimeAsFileTime(\x26""ft);\x0a"
"#endif\x0a"
"#else\x0a"
"  GetSystemTimeAsFileTime(\x26""ft);\x0a"
"#endif\x0a"
"\x0a"
"  filetime_duration d{(static_cast<__int64>(ft.dwHighDateTime) << 32) \x7c\x0a"
"                       static_cast<__int64>(ft.dwLowDateTime)};\x0a"
"  return time_point(duration_cast<duration>(d - nt_to_unix_epoch));\x0a"
"#else\x0a"
"#if defined(_LIBCPP_USE_CLOCK_GETTIME) \x26\x26 defined(CLOCK_REALTIME)\x0a"
"  struct timespec tp;\x0a"
"  if (0 \x21= clock_gettime(CLOCK_REALTIME, \x26tp))\x0a"
"    __throw_system_error(errno, \x22""clock_gettime(CLOCK_REALTIME) failed\x22);\x0a"
"  return time_point(seconds(tp.tv_sec) + microseconds(tp.tv_nsec / 1000));\x0a"
"#else\x0a"
"    timeval tv;\x0a"
"    gettimeofday(\x26tv, 0);\x0a"
"    return time_point(seconds(tv.tv_sec) + microseconds(tv.tv_usec));\x0a"
"#endif // _LIBCPP_USE_CLOCK_GETTIME \x26\x26 CLOCK_REALTIME\x0a"
"#endif\x0a"
"}\x0a"
"\x0a"
"time_t\x0a"
"system_clock\x3a\x3ato_time_t(const time_point\x26 t) _NOEXCEPT\x0a"
"{\x0a"
"    return time_t(duration_cast<seconds>(t.time_since_epoch()).count());\x0a"
"}\x0a"
"\x0a"
"system_clock\x3a\x3atime_point\x0a"
"system_clock\x3a\x3a""from_time_t(time_t t) _NOEXCEPT\x0a"
"{\x0a"
"    return system_clock\x3a\x3atime_point(seconds(t));\x0a"
"}\x0a"
"\x0a"
"#ifndef _LIBCPP_HAS_NO_MONOTONIC_CLOCK\x0a"
"// steady_clock\x0a"
"//\x0a"
"// Warning\x3a  If this is not truly steady, then it is non-conforming.  It is\x0a"
"//  better for it to not exist and have the rest of libc++ use system_clock\x0a"
"//  instead.\x0a"
"\x0a"
"const bool steady_clock\x3a\x3ais_steady;\x0a"
"\x0a"
"#if defined(__APPLE__)\x0a"
"\x0a"
"// Darwin libc versions >= 1133 provide ns precision via CLOCK_UPTIME_RAW\x0a"
"#if defined(_LIBCPP_USE_CLOCK_GETTIME) \x26\x26 defined(CLOCK_UPTIME_RAW)\x0a"
"steady_clock\x3a\x3atime_point\x0a"
"steady_clock\x3a\x3anow() _NOEXCEPT\x0a"
"{\x0a"
"    struct timespec tp;\x0a"
"    if (0 \x21= clock_gettime(CLOCK_UPTIME_RAW, \x26tp))\x0a"
"        __throw_system_error(errno, \x22""clock_gettime(CLOCK_UPTIME_RAW) failed\x22);\x0a"
"    return time_point(seconds(tp.tv_sec) + nanoseconds(tp.tv_nsec));\x0a"
"}\x0a"
"\x0a"
"#else\x0a"
"//   mach_absolute_time() * MachInfo.numer / MachInfo.denom is the number of\x0a"
"//   nanoseconds since the computer booted up.  MachInfo.numer and MachInfo.denom\x0a"
"//   are run time constants supplied by the OS.  This clock has no relationship\x0a"
"//   to the Gregorian calendar.  It's main use is as a high resolution timer.\x0a"
"\x0a"
"// MachInfo.numer / MachInfo.denom is often 1 on the latest equipment.  Specialize\x0a"
"//   for that case as an optimization.\x0a"
"\x0a"
"static\x0a"
"steady_clock\x3a\x3arep\x0a"
"steady_simplified()\x0a"
"{\x0a"
"    return static_cast<steady_clock\x3a\x3arep>(mach_absolute_time());\x0a"
"}\x0a"
"\x0a"
"static\x0a"
"double\x0a"
"compute_steady_factor()\x0a"
"{\x0a"
"    mach_timebase_info_data_t MachInfo;\x0a"
"    mach_timebase_info(\x26MachInfo);\x0a"
"    return static_cast<double>(MachInfo.numer) / MachInfo.denom;\x0a"
"}\x0a"
"\x0a"
"static\x0a"
"steady_clock\x3a\x3arep\x0a"
"steady_full()\x0a"
"{\x0a"
"    static const double factor = compute_steady_factor();\x0a"
"    return static_cast<steady_clock\x3a\x3arep>(mach_absolute_time() * factor);\x0a"
"}\x0a"
"\x0a"
"typedef steady_clock\x3a\x3arep (*FP)();\x0a"
"\x0a"
"static\x0a"
"FP\x0a"
"init_steady_clock()\x0a"
"{\x0a"
"    mach_timebase_info_data_t MachInfo;\x0a"
"    mach_timebase_info(\x26MachInfo);\x0a"
"    if (MachInfo.numer == MachInfo.denom)\x0a"
"        return \x26steady_simplified;\x0a"
"    return \x26steady_full;\x0a"
"}\x0a"
"\x0a"
"steady_clock\x3a\x3atime_point\x0a"
"steady_clock\x3a\x3anow() _NOEXCEPT\x0a"
"{\x0a"
"    static FP fp = init_steady_clock();\x0a"
"    return time_point(duration(fp()));\x0a"
"}\x0a"
"#endif // defined(_LIBCPP_USE_CLOCK_GETTIME) \x26\x26 defined(CLOCK_UPTIME_RAW)\x0a"
"\x0a"
"#elif defined(_LIBCPP_WIN32API)\x0a"
"\x0a"
"// https\x3a//msdn.microsoft.com/en-us/library/windows/desktop/ms644905(v=vs.85).aspx says\x3a\x0a"
"//    If the function fails, the return value is zero. <snip>\x0a"
"//    On systems that run Windows XP or later, the function will always succeed \x0a"
"//      and will thus never return zero.\x0a"
"\x0a"
"static LARGE_INTEGER\x0a"
"__QueryPerformanceFrequency()\x0a"
"{\x0a"
"\x09LARGE_INTEGER val;\x0a"
"\x09(void) QueryPerformanceFrequency(\x26val);\x0a"
"\x09return val;\x0a"
"}\x0a"
"\x0a"
"steady_clock\x3a\x3atime_point\x0a"
"steady_clock\x3a\x3anow() _NOEXCEPT\x0a"
"{\x0a"
"  static const LARGE_INTEGER freq = __QueryPerformanceFrequency();\x0a"
"\x0a"
"  LARGE_INTEGER counter;\x0a"
"  (void) QueryPerformanceCounter(\x26""counter);\x0a"
"  return time_point(duration(counter.QuadPart * nano\x3a\x3a""den / freq.QuadPart));\x0a"
"}\x0a"
"\x0a"
"#elif defined(CLOCK_MONOTONIC)\x0a"
"\x0a"
"// On Apple platforms only CLOCK_UPTIME_RAW or mach_absolute_time are able to\x0a"
"// time functions in the nanosecond range. Thus, they are the only acceptable\x0a"
"// implementations of steady_clock.\x0a"
"#ifdef __APPLE__\x0a"
"#error \x22Never use CLOCK_MONOTONIC for steady_clock\x3a\x3anow on Apple platforms\x22\x0a"
"#endif\x0a"
"\x0a"
"steady_clock\x3a\x3atime_point\x0a"
"steady_clock\x3a\x3anow() _NOEXCEPT\x0a"
"{\x0a"
"    struct timespec tp;\x0a"
"    if (0 \x21= clock_gettime(CLOCK_MONOTONIC, \x26tp))\x0a"
"        __throw_system_error(errno, \x22""clock_gettime(CLOCK_MONOTONIC) failed\x22);\x0a"
"    return time_point(seconds(tp.tv_sec) + nanoseconds(tp.tv_nsec));\x0a"
"}\x0a"
"\x0a"
"#else\x0a"
"#error \x22Monotonic clock not implemented\x22\x0a"
"#endif\x0a"
"\x0a"
"#endif // \x21_LIBCPP_HAS_NO_MONOTONIC_CLOCK\x0a"
"\x0a"
"}\x0a"
"\x0a"
"_LIBCPP_END_NAMESPACE_STD\x0a"
"", 6714 ); }