#include <string_view>
namespace divine::str::dios {
extern const std::string_view libm_k_cos_c( 
"/* \x40(#)k_cos.c 5.1 93/09/24 */\x0a"
"/*\x0a"
" * ====================================================\x0a"
" * Copyright (C) 1993 by Sun Microsystems, Inc. All rights reserved.\x0a"
" *\x0a"
" * Developed at SunPro, a Sun Microsystems, Inc. business.\x0a"
" * Permission to use, copy, modify, and distribute this\x0a"
" * software is freely granted, provided that this notice \x0a"
" * is preserved.\x0a"
" * ====================================================\x0a"
" */\x0a"
"\x0a"
"/*\x0a"
" * __kernel_cos( x,  y )\x0a"
" * kernel cos function on \x5b-pi/4, pi/4\x5d, pi/4 \x7e 0.785398164\x0a"
" * Input x is assumed to be bounded by \x7epi/4 in magnitude.\x0a"
" * Input y is the tail of x. \x0a"
" *\x0a"
" * Algorithm\x0a"
" *\x09""1. Since cos(-x) = cos(x), we need only to consider positive x.\x0a"
" *\x09""2. if x < 2^-27 (hx<0x3e400000 0), return 1 with inexact if x\x21=0.\x0a"
" *\x09""3. cos(x) is approximated by a polynomial of degree 14 on\x0a"
" *\x09   \x5b""0,pi/4\x5d\x0a"
" *\x09\x09  \x09                 4            14\x0a"
" *\x09   \x09""cos(x) \x7e 1 - x*x/2 + C1*x + ... + C6*x\x0a"
" *\x09   where the Remes error is\x0a"
" *\x09\x0a"
" * \x09\x7c              2     4     6     8     10    12     14 \x7c     -58\x0a"
" * \x09\x7c""cos(x)-(1-.5*x +C1*x +C2*x +C3*x +C4*x +C5*x  +C6*x  )\x7c <= 2\x0a"
" * \x09\x7c    \x09\x09\x09\x09\x09               \x7c \x0a"
" * \x0a"
" * \x09               4     6     8     10    12     14 \x0a"
" *\x09""4. let r = C1*x +C2*x +C3*x +C4*x +C5*x  +C6*x  , then\x0a"
" *\x09       cos(x) = 1 - x*x/2 + r\x0a"
" *\x09   since cos(x+y) \x7e cos(x) - sin(x)*y \x0a"
" *\x09\x09\x09  \x7e cos(x) - x*y,\x0a"
" *\x09   a correction term is necessary in cos(x) and hence\x0a"
" *\x09\x09""cos(x+y) = 1 - (x*x/2 - (r - x*y))\x0a"
" *\x09   For better accuracy when x > 0.3, let qx = \x7cx\x7c/4 with\x0a"
" *\x09   the last 32 bits mask off, and if x > 0.78125, let qx = 0.28125.\x0a"
" *\x09   Then\x0a"
" *\x09\x09""cos(x+y) = (1-qx) - ((x*x/2-qx) - (r-x*y)).\x0a"
" *\x09   Note that 1-qx and (x*x/2-qx) is EXACT here, and the\x0a"
" *\x09   magnitude of the latter is at least a quarter of x*x/2,\x0a"
" *\x09   thus, reducing the rounding error in the subtraction.\x0a"
" */\x0a"
"\x0a"
"#include \x22math.h\x22\x0a"
"#include \x22math_private.h\x22\x0a"
"\x0a"
"static const double \x0a"
"one =  1.00000000000000000000e+00, /* 0x3FF00000, 0x00000000 */\x0a"
"C1  =  4.16666666666666019037e-02, /* 0x3FA55555, 0x5555554C */\x0a"
"C2  = -1.38888888888741095749e-03, /* 0xBF56C16C, 0x16C15177 */\x0a"
"C3  =  2.48015872894767294178e-05, /* 0x3EFA01A0, 0x19CB1590 */\x0a"
"C4  = -2.75573143513906633035e-07, /* 0xBE927E4F, 0x809C52AD */\x0a"
"C5  =  2.08757232129817482790e-09, /* 0x3E21EE9E, 0xBDB4B1C4 */\x0a"
"C6  = -1.13596475577881948265e-11; /* 0xBDA8FAE9, 0xBE8838D4 */\x0a"
"\x0a"
"double\x0a"
"__kernel_cos(double x, double y)\x0a"
"{\x0a"
"\x09""double a,hz,z,r,qx;\x0a"
"\x09int32_t ix;\x0a"
"\x09GET_HIGH_WORD(ix,x);\x0a"
"\x09ix \x26= 0x7fffffff;\x09\x09\x09/* ix = \x7cx\x7c's high word*/\x0a"
"\x09if(ix<0x3e400000) {\x09\x09\x09/* if x < 2**27 */\x0a"
"\x09    if(((int)x)==0) return one;\x09\x09/* generate inexact */\x0a"
"\x09}\x0a"
"\x09z  = x*x;\x0a"
"\x09r  = z*(C1+z*(C2+z*(C3+z*(C4+z*(C5+z*C6)))));\x0a"
"\x09if(ix < 0x3FD33333) \x09\x09\x09/* if \x7cx\x7c < 0.3 */ \x0a"
"\x09    return one - (0.5*z - (z*r - x*y));\x0a"
"\x09""else {\x0a"
"\x09    if(ix > 0x3fe90000) {\x09\x09/* x > 0.78125 */\x0a"
"\x09\x09qx = 0.28125;\x0a"
"\x09    } else {\x0a"
"\x09        INSERT_WORDS(qx,ix-0x00200000,0);\x09/* x/4 */\x0a"
"\x09    }\x0a"
"\x09    hz = 0.5*z-qx;\x0a"
"\x09    a  = one-qx;\x0a"
"\x09    return a - (hz - (z*r-x*y));\x0a"
"\x09}\x0a"
"}\x0a"
"", 2918 ); }