#include <string_view>
namespace divine::str::dios {
extern const std::string_view libm_ld80_e_expl_c( 
"/*\x09\x24OpenBSD\x3a e_expl.c,v 1.3 2013/11/12 20\x3a""35\x3a""19 martynas Exp \x24\x09*/\x0a"
"\x0a"
"/*\x0a"
" * Copyright (c) 2008 Stephen L. Moshier <steve\x40moshier.net>\x0a"
" *\x0a"
" * Permission to use, copy, modify, and distribute this software for any\x0a"
" * purpose with or without fee is hereby granted, provided that the above\x0a"
" * copyright notice and this permission notice appear in all copies.\x0a"
" *\x0a"
" * THE SOFTWARE IS PROVIDED \x22""AS IS\x22 AND THE AUTHOR DISCLAIMS ALL WARRANTIES\x0a"
" * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\x0a"
" * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\x0a"
" * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\x0a"
" * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\x0a"
" * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\x0a"
" * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\x0a"
" */\x0a"
"\x0a"
"/*\x09\x09\x09\x09\x09\x09\x09""expl.c\x0a"
" *\x0a"
" *\x09""Exponential function, long double precision\x0a"
" *\x0a"
" *\x0a"
" *\x0a"
" * SYNOPSIS\x3a\x0a"
" *\x0a"
" * long double x, y, expl();\x0a"
" *\x0a"
" * y = expl( x );\x0a"
" *\x0a"
" *\x0a"
" *\x0a"
" * DESCRIPTION\x3a\x0a"
" *\x0a"
" * Returns e (2.71828...) raised to the x power.\x0a"
" *\x0a"
" * Range reduction is accomplished by separating the argument\x0a"
" * into an integer k and fraction f such that\x0a"
" *\x0a"
" *     x    k  f\x0a"
" *    e  = 2  e.\x0a"
" *\x0a"
" * A Pade' form of degree 2/3 is used to approximate exp(f) - 1\x0a"
" * in the basic range \x5b-0.5 ln 2, 0.5 ln 2\x5d.\x0a"
" *\x0a"
" *\x0a"
" * ACCURACY\x3a\x0a"
" *\x0a"
" *                      Relative error\x3a\x0a"
" * arithmetic   domain     # trials      peak         rms\x0a"
" *    IEEE      +-10000     50000       1.12e-19    2.81e-20\x0a"
" *\x0a"
" *\x0a"
" * Error amplification in the exponential function can be\x0a"
" * a serious matter.  The error propagation involves\x0a"
" * exp( X(1+delta) ) = exp(X) ( 1 + X*delta + ... ),\x0a"
" * which shows that a 1 lsb error in representing X produces\x0a"
" * a relative error of X times 1 lsb in the function.\x0a"
" * While the routine gives an accurate result for arguments\x0a"
" * that are exactly represented by a long double precision\x0a"
" * computer number, the result contains amplified roundoff\x0a"
" * error for large arguments not exactly represented.\x0a"
" *\x0a"
" *\x0a"
" * ERROR MESSAGES\x3a\x0a"
" *\x0a"
" *   message         condition      value returned\x0a"
" * exp underflow    x < MINLOG         0.0\x0a"
" * exp overflow     x > MAXLOG         MAXNUM\x0a"
" *\x0a"
" */\x0a"
"\x0a"
"/*\x09""Exponential function\x09*/\x0a"
"\x0a"
"#include <math.h>\x0a"
"\x0a"
"#include \x22math_private.h\x22\x0a"
"\x0a"
"static long double P\x5b""3\x5d = {\x0a"
" 1.2617719307481059087798E-4L,\x0a"
" 3.0299440770744196129956E-2L,\x0a"
" 9.9999999999999999991025E-1L,\x0a"
"};\x0a"
"static long double Q\x5b""4\x5d = {\x0a"
" 3.0019850513866445504159E-6L,\x0a"
" 2.5244834034968410419224E-3L,\x0a"
" 2.2726554820815502876593E-1L,\x0a"
" 2.0000000000000000000897E0L,\x0a"
"};\x0a"
"static const long double C1 = 6.9314575195312500000000E-1L;\x0a"
"static const long double C2 = 1.4286068203094172321215E-6L;\x0a"
"static const long double MAXLOGL = 1.1356523406294143949492E4L;\x0a"
"static const long double MINLOGL = -1.13994985314888605586758E4L;\x0a"
"static const long double LOG2EL = 1.4426950408889634073599E0L;\x0a"
"\x0a"
"long double\x0a"
"expl(long double x)\x0a"
"{\x0a"
"long double px, xx;\x0a"
"int n;\x0a"
"\x0a"
"if( isnan(x) )\x0a"
"\x09return(x);\x0a"
"if( x > MAXLOGL)\x0a"
"\x09return( INFINITY );\x0a"
"\x0a"
"if( x < MINLOGL )\x0a"
"\x09return(0.0L);\x0a"
"\x0a"
"/* Express e**x = e**g 2**n\x0a"
" *   = e**g e**( n loge(2) )\x0a"
" *   = e**( g + n loge(2) )\x0a"
" */\x0a"
"px = floorl( LOG2EL * x + 0.5L ); /* floor() truncates toward -infinity. */\x0a"
"n = px;\x0a"
"x -= px * C1;\x0a"
"x -= px * C2;\x0a"
"\x0a"
"\x0a"
"/* rational approximation for exponential\x0a"
" * of the fractional part\x3a\x0a"
" * e**x =  1 + 2x P(x**2)/( Q(x**2) - P(x**2) )\x0a"
" */\x0a"
"xx = x * x;\x0a"
"px = x * __polevll( xx, P, 2 );\x0a"
"x =  px/( __polevll( xx, Q, 3 ) - px );\x0a"
"x = 1.0L + ldexpl( x, 1 );\x0a"
"\x0a"
"x = ldexpl( x, n );\x0a"
"return(x);\x0a"
"}\x0a"
"", 3514 ); }