#include <string_view>
namespace divine::str::dios {
extern const std::string_view libm_ld80_s_expm1l_c( 
"/*\x09\x24OpenBSD\x3a s_expm1l.c,v 1.2 2011/07/20 21\x3a""02\x3a""51 martynas Exp \x24\x09*/\x0a"
"\x0a"
"/*\x0a"
" * Copyright (c) 2008 Stephen L. Moshier <steve\x40moshier.net>\x0a"
" *\x0a"
" * Permission to use, copy, modify, and distribute this software for any\x0a"
" * purpose with or without fee is hereby granted, provided that the above\x0a"
" * copyright notice and this permission notice appear in all copies.\x0a"
" *\x0a"
" * THE SOFTWARE IS PROVIDED \x22""AS IS\x22 AND THE AUTHOR DISCLAIMS ALL WARRANTIES\x0a"
" * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\x0a"
" * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\x0a"
" * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\x0a"
" * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\x0a"
" * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\x0a"
" * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\x0a"
" */\x0a"
"\x0a"
"/*\x09\x09\x09\x09\x09\x09\x09""expm1l.c\x0a"
" *\x0a"
" *\x09""Exponential function, minus 1\x0a"
" *      Long double precision\x0a"
" *\x0a"
" *\x0a"
" * SYNOPSIS\x3a\x0a"
" *\x0a"
" * long double x, y, expm1l();\x0a"
" *\x0a"
" * y = expm1l( x );\x0a"
" *\x0a"
" *\x0a"
" *\x0a"
" * DESCRIPTION\x3a\x0a"
" *\x0a"
" * Returns e (2.71828...) raised to the x power, minus 1.\x0a"
" *\x0a"
" * Range reduction is accomplished by separating the argument\x0a"
" * into an integer k and fraction f such that\x0a"
" *\x0a"
" *     x    k  f\x0a"
" *    e  = 2  e.\x0a"
" *\x0a"
" * An expansion x + .5 x^2 + x^3 R(x) approximates exp(f) - 1\x0a"
" * in the basic range \x5b-0.5 ln 2, 0.5 ln 2\x5d.\x0a"
" *\x0a"
" *\x0a"
" * ACCURACY\x3a\x0a"
" *\x0a"
" *                      Relative error\x3a\x0a"
" * arithmetic   domain     # trials      peak         rms\x0a"
" *    IEEE    -45,+MAXLOG   200,000     1.2e-19     2.5e-20\x0a"
" *\x0a"
" * ERROR MESSAGES\x3a\x0a"
" *\x0a"
" *   message         condition      value returned\x0a"
" * expm1l overflow   x > MAXLOG         MAXNUM\x0a"
" *\x0a"
" */\x0a"
"\x0a"
"#include <math.h>\x0a"
"\x0a"
"static const long double MAXLOGL = 1.1356523406294143949492E4L;\x0a"
"\x0a"
"/* exp(x) - 1 = x + 0.5 x^2 + x^3 P(x)/Q(x)\x0a"
"   -.5 ln 2  <  x  <  .5 ln 2\x0a"
"   Theoretical peak relative error = 3.4e-22  */\x0a"
"\x0a"
"static const long double\x0a"
"  P0 = -1.586135578666346600772998894928250240826E4L,\x0a"
"  P1 =  2.642771505685952966904660652518429479531E3L,\x0a"
"  P2 = -3.423199068835684263987132888286791620673E2L,\x0a"
"  P3 =  1.800826371455042224581246202420972737840E1L,\x0a"
"  P4 = -5.238523121205561042771939008061958820811E-1L,\x0a"
"\x0a"
"  Q0 = -9.516813471998079611319047060563358064497E4L,\x0a"
"  Q1 =  3.964866271411091674556850458227710004570E4L,\x0a"
"  Q2 = -7.207678383830091850230366618190187434796E3L,\x0a"
"  Q3 =  7.206038318724600171970199625081491823079E2L,\x0a"
"  Q4 = -4.002027679107076077238836622982900945173E1L,\x0a"
"  /* Q5 = 1.000000000000000000000000000000000000000E0 */\x0a"
"\x0a"
"/* C1 + C2 = ln 2 */\x0a"
"C1 = 6.93145751953125E-1L,\x0a"
"C2 = 1.428606820309417232121458176568075500134E-6L,\x0a"
"/* ln 2^-65 */\x0a"
"minarg = -4.5054566736396445112120088E1L;\x0a"
"static const long double huge = 0x1p10000L;\x0a"
"\x0a"
"long double\x0a"
"expm1l(long double x)\x0a"
"{\x0a"
"long double px, qx, xx;\x0a"
"int k;\x0a"
"\x0a"
"/* Overflow.  */\x0a"
"if (x > MAXLOGL)\x0a"
"  return (huge*huge);\x09/* overflow */\x0a"
"\x0a"
"if (x == 0.0)\x0a"
"  return x;\x0a"
"\x0a"
"/* Minimum value.  */\x0a"
"if (x < minarg)\x0a"
"  return -1.0L;\x0a"
"\x0a"
"xx = C1 + C2;\x0a"
"\x0a"
"/* Express x = ln 2 (k + remainder), remainder not exceeding 1/2. */\x0a"
"px = floorl (0.5 + x / xx);\x0a"
"k = px;\x0a"
"/* remainder times ln 2 */\x0a"
"x -= px * C1;\x0a"
"x -= px * C2;\x0a"
"\x0a"
"/* Approximate exp(remainder ln 2).  */\x0a"
"px = (((( P4 * x\x0a"
"\x09 + P3) * x\x0a"
"\x09+ P2) * x\x0a"
"       + P1) * x\x0a"
"      + P0) * x;\x0a"
"\x0a"
"qx = (((( x\x0a"
"\x09 + Q4) * x\x0a"
"\x09+ Q3) * x\x0a"
"       + Q2) * x\x0a"
"      + Q1) * x\x0a"
"     + Q0;\x0a"
"\x0a"
"xx = x * x;\x0a"
"qx = x + (0.5 * xx + xx * px / qx);\x0a"
"\x0a"
"/* exp(x) = exp(k ln 2) exp(remainder ln 2) = 2^k exp(remainder ln 2).\x0a"
"   We have qx = exp(remainder ln 2) - 1, so\x0a"
"   exp(x) - 1  =  2^k (qx + 1) - 1  =  2^k qx + 2^k - 1.  */\x0a"
"px = ldexpl(1.0L, k);\x0a"
"x = px * qx + (px - 1.0);\x0a"
"return x;\x0a"
"}\x0a"
"", 3595 ); }