#include <string_view>
namespace divine::str::dios {
extern const std::string_view libm_s_ctan_c( 
"/*\x09\x24OpenBSD\x3a s_ctan.c,v 1.6 2013/07/03 04\x3a""46\x3a""36 espie Exp \x24\x09*/\x0a"
"/*\x0a"
" * Copyright (c) 2008 Stephen L. Moshier <steve\x40moshier.net>\x0a"
" *\x0a"
" * Permission to use, copy, modify, and distribute this software for any\x0a"
" * purpose with or without fee is hereby granted, provided that the above\x0a"
" * copyright notice and this permission notice appear in all copies.\x0a"
" *\x0a"
" * THE SOFTWARE IS PROVIDED \x22""AS IS\x22 AND THE AUTHOR DISCLAIMS ALL WARRANTIES\x0a"
" * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\x0a"
" * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\x0a"
" * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\x0a"
" * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\x0a"
" * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\x0a"
" * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\x0a"
" */\x0a"
"\x0a"
"/*\x09\x09\x09\x09\x09\x09\x09""ctan()\x0a"
" *\x0a"
" *\x09""Complex circular tangent\x0a"
" *\x0a"
" *\x0a"
" *\x0a"
" * SYNOPSIS\x3a\x0a"
" *\x0a"
" * double complex ctan();\x0a"
" * double complex z, w;\x0a"
" *\x0a"
" * w = ctan (z);\x0a"
" *\x0a"
" *\x0a"
" *\x0a"
" * DESCRIPTION\x3a\x0a"
" *\x0a"
" * If\x0a"
" *     z = x + iy,\x0a"
" *\x0a"
" * then\x0a"
" *\x0a"
" *           sin 2x  +  i sinh 2y\x0a"
" *     w  =  --------------------.\x0a"
" *            cos 2x  +  cosh 2y\x0a"
" *\x0a"
" * On the real axis the denominator is zero at odd multiples\x0a"
" * of PI/2.  The denominator is evaluated by its Taylor\x0a"
" * series near these points.\x0a"
" *\x0a"
" * ctan(z) = -i ctanh(iz).\x0a"
" *\x0a"
" * ACCURACY\x3a\x0a"
" *\x0a"
" *                      Relative error\x3a\x0a"
" * arithmetic   domain     # trials      peak         rms\x0a"
" *    DEC       -10,+10      5200       7.1e-17     1.6e-17\x0a"
" *    IEEE      -10,+10     30000       7.2e-16     1.2e-16\x0a"
" * Also tested by ctan * ccot = 1 and catan(ctan(z))  =  z.\x0a"
" */\x0a"
"\x0a"
"#include <complex.h>\x0a"
"#include <float.h>\x0a"
"#include <math.h>\x0a"
"\x0a"
"#define MACHEP 1.1e-16\x0a"
"#define MAXNUM 1.0e308\x0a"
"\x0a"
"static const double DP1 = 3.14159265160560607910E0;\x0a"
"static const double DP2 = 1.98418714791870343106E-9;\x0a"
"static const double DP3 = 1.14423774522196636802E-17;\x0a"
"\x0a"
"static double\x0a"
"_redupi(double x)\x0a"
"{\x0a"
"\x09""double t;\x0a"
"\x09long i;\x0a"
"\x0a"
"\x09t = x/M_PI;\x0a"
"\x09if (t >= 0.0)\x0a"
"\x09\x09t += 0.5;\x0a"
"\x09""else\x0a"
"\x09\x09t -= 0.5;\x0a"
"\x0a"
"\x09i = t;\x09/* the multiple */\x0a"
"\x09t = i;\x0a"
"\x09t = ((x - t * DP1) - t * DP2) - t * DP3;\x0a"
"\x09return (t);\x0a"
"}\x0a"
"\x0a"
"/*  Taylor series expansion for cosh(2y) - cos(2x)\x09*/\x0a"
"\x0a"
"static double\x0a"
"_ctans(double complex z)\x0a"
"{\x0a"
"\x09""double f, x, x2, y, y2, rn, t;\x0a"
"\x09""double d;\x0a"
"\x0a"
"\x09x = fabs (2.0 * creal (z));\x0a"
"\x09y = fabs (2.0 * cimag(z));\x0a"
"\x0a"
"\x09x = _redupi(x);\x0a"
"\x0a"
"\x09x = x * x;\x0a"
"\x09y = y * y;\x0a"
"\x09x2 = 1.0;\x0a"
"\x09y2 = 1.0;\x0a"
"\x09""f = 1.0;\x0a"
"\x09rn = 0.0;\x0a"
"\x09""d = 0.0;\x0a"
"\x09""do {\x0a"
"\x09\x09rn += 1.0;\x0a"
"\x09\x09""f *= rn;\x0a"
"\x09\x09rn += 1.0;\x0a"
"\x09\x09""f *= rn;\x0a"
"\x09\x09x2 *= x;\x0a"
"\x09\x09y2 *= y;\x0a"
"\x09\x09t = y2 + x2;\x0a"
"\x09\x09t /= f;\x0a"
"\x09\x09""d += t;\x0a"
"\x0a"
"\x09\x09rn += 1.0;\x0a"
"\x09\x09""f *= rn;\x0a"
"\x09\x09rn += 1.0;\x0a"
"\x09\x09""f *= rn;\x0a"
"\x09\x09x2 *= x;\x0a"
"\x09\x09y2 *= y;\x0a"
"\x09\x09t = y2 - x2;\x0a"
"\x09\x09t /= f;\x0a"
"\x09\x09""d += t;\x0a"
"\x09}\x0a"
"\x09while (fabs(t/d) > MACHEP)\x0a"
"\x09\x09;\x0a"
"\x09return (d);\x0a"
"}\x0a"
"\x0a"
"double complex\x0a"
"ctan(double complex z)\x0a"
"{\x0a"
"\x09""double complex w;\x0a"
"\x09""double d;\x0a"
"\x0a"
"\x09""d = cos (2.0 * creal (z)) + cosh (2.0 * cimag (z));\x0a"
"\x0a"
"\x09if (fabs(d) < 0.25)\x0a"
"\x09\x09""d = _ctans (z);\x0a"
"\x0a"
"\x09if (d == 0.0) {\x0a"
"\x09\x09/*mtherr (\x22""ctan\x22, OVERFLOW);*/\x0a"
"\x09\x09w = MAXNUM + MAXNUM * I;\x0a"
"\x09\x09return (w);\x0a"
"\x09}\x0a"
"\x0a"
"\x09w = sin (2.0 * creal(z)) / d + (sinh (2.0 * cimag(z)) / d) * I;\x0a"
"\x09return (w);\x0a"
"}\x0a"
"\x0a"
"#if\x09LDBL_MANT_DIG == DBL_MANT_DIG\x0a"
"__strong_alias(ctanl, ctan);\x0a"
"#endif\x09/* LDBL_MANT_DIG == DBL_MANT_DIG */\x0a"
"", 3134 ); }