#include <string_view>
namespace divine::str::doc {
extern const std::string_view manual_sim_md( 
"# Interactive Debugging {#sim}\x0a"
"\x0a"
"DIVINE comes with an interactive debugger, available as \x60""divine sim\x60. The\x0a"
"debugger loads programs the same way \x60verify\x60 and other DIVINE commands do, so\x0a"
"you can run it on standalone C or C++ source files directly, or you can compile\x0a"
"larger programs into bitcode and load that.\x0a"
"\x0a"
"## Tutorial\x0a"
"\x0a"
"Let's say you have a small C program which you wish to debug. We will refer to\x0a"
"this program as \x60program.c\x60. To load the program into the debugger, simply execute\x0a"
"\x0a"
"    \x24 divine sim program.c\x0a"
"\x0a"
"and DIVINE will take care of compiling and linking your program. It will load\x0a"
"the resulting bitcode but will not execute it immediately\x3a instead, \x60sim\x60 will\x0a"
"present a prompt to you, looking like this\x3a\x0a"
"\x0a"
"    # executing __boot at /divine/src/dios/dios.cpp\x3a""79\x0a"
"    >\x0a"
"\x0a"
"The \x60__boot\x60 function is common to all DIVINE-compiled programs and belongs to\x0a"
"DiOS, our minimalist operating system. When debugging user-mode programs, the\x0a"
"good first command to run is\x0a"
"\x0a"
"    > start\x0a"
"\x0a"
"which will start executing the program until it enters the \x60main\x60 function\x3a\x0a"
"\x0a"
"    # a new program state was stored as #1\x0a"
"    # active threads\x3a \x5b""0\x3a""0\x5d\x0a"
"    # a new program state was stored as #2\x0a"
"    # active threads\x3a \x5b""0\x3a""0\x5d\x0a"
"    # executing main at program.c\x3a""14\x0a"
"    >\x0a"
"\x0a"
"We can already see a few DIVINE-specific features of the debugger. First,\x0a"
"program states are stored and retained for future reference. Second, thread\x0a"
"switching is quite explicit -- every time a scheduling decision is made, \x60sim\x60\x0a"
"informs you of this fact. We will look at how to influence these decisions\x0a"
"later.\x0a"
"\x0a"
"Now is a good time to familiarise ourselves with how to inspect the\x0a"
"program. There are two commands for listing the program itself\x3a \x60source\x60 and\x0a"
"\x60""bitcode\x60 and each will print the currently executing function in the\x0a"
"appropriate form (the original C source code and LLVM bitcode,\x0a"
"respectively). Additionally, when printing bitcode, the current values of all\x0a"
"LLVM registers are shown as inline comments\x3a\x0a"
"\x0a"
"      label \x25""entry\x3a\x0a"
"    >>  \x25""01 = alloca \x5bi32 1 d\x5d                                  # \x5bglobal* 0 0 uun\x5d\x0a"
"        dbg.declare \x0a"
"        \x25""03 = getelementptr \x25""01 \x5bi32 0 d\x5d \x5bi32 0 d\x5d             # \x5bglobal* 0 0 uun\x5d\x0a"
"        call \x40init \x25""03 \x0a"
"\x0a"
"Besides printing the currently executing function, both \x60source\x60 and \x60""bitcode\x60\x0a"
"can print code corresponding to other functions; in fact, by default they print\x0a"
"whatever function the debugger variable \x60\x24""frame\x60 refers to. To print the source\x0a"
"code of the current function's caller, you can issue\x0a"
"\x0a"
"    > source caller\x0a"
"         97 void _start( int l, int argc, char **argv, char **envp ) {\x0a"
"    >>   98     int res = __execute_main( l, argc, argv, envp );\x0a"
"         99     exit( res );\x0a"
"        100 }\x0a"
"\x0a"
"To inspect data, we can instead use \x60show\x60 and \x60inspect\x60. We have mentioned\x0a"
"\x60\x24""frame\x60 earlier\x3a there is, in fact, a number of variables set by \x60sim\x60. The\x0a"
"most interesting of those is \x60\x24_\x60 which normally refers to the most interesting\x0a"
"object at hand, typically the executing frame. By default, \x60show\x60 will print\x0a"
"the content of \x60\x24_\x60 (like many other commands). However, when we pass an\x0a"
"explicit parameter to these commands, the difference between \x60show\x60 and\x0a"
"\x60inspect\x60 becomes apparent\x3a the latter also sets \x60\x24_\x60 to its parameter. This\x0a"
"makes \x60inspect\x60 more suitable for exploring more complex data, while \x60show\x60 is\x0a"
"useful for quickly glancing at nearby values\x3a\x0a"
"\x0a"
"    > step --count 2\x0a"
"    > show\x0a"
"    attributes\x3a\x0a"
"        address\x3a heap* 9cd25662 0+0\x0a"
"        shared\x3a  0\x0a"
"        pc\x3a      code* 2 2\x0a"
"        insn\x3a    dbg.declare \x0a"
"        location\x3a program.c\x3a""16\x0a"
"        symbol\x3a  main\x0a"
"    .x\x3a\x0a"
"        type\x3a    int\x5b\x5d\x0a"
"        .\x5b""0\x5d\x3a\x0a"
"            type\x3a int\x0a"
"            value\x3a \x5bi32 0 u\x5d\x0a"
"        .\x5b""1\x5d\x3a\x0a"
"            type\x3a int\x0a"
"            value\x3a \x5bi32 0 u\x5d\x0a"
"        .\x5b""2\x5d\x3a\x0a"
"            type\x3a int\x0a"
"            value\x3a \x5bi32 0 u\x5d\x0a"
"        .\x5b""3\x5d\x3a\x0a"
"            type\x3a int\x0a"
"            value\x3a \x5bi32 0 u\x5d\x0a"
"    related\x3a     \x5b caller \x5d\x0a"
"\x0a"
"This is how a frame is presented when we look at it with \x60show\x60.\x0a"
"\x0a"
"## Collecting Information\x0a"
"\x0a"
"Apart from \x60show\x60 and \x60inspect\x60 which simply print structured program data to\x0a"
"the screen, there are additional commands for data extraction. First,\x0a"
"\x60""backtrace\x60 will print the entire stack trace in one go, by default starting\x0a"
"with the currently executing frame. It is also possible to obtain *all* stack\x0a"
"traces reachable from a given heap variable, e.g.\x0a"
"\x0a"
"    > backtrace \x24state\x0a"
"    # backtrace 1\x3a\x0a"
"      __dios\x3a\x3a_InterruptMask<true>\x3a\x3aWithout\x3a\x3aWithout(__dios\x3a\x3a_InterruptMask<true>\x26)\x0a"
"          at /divine/include/libc/include/sys/interrupt.h\x3a""42\x0a"
"      _pthread_join(__dios\x3a\x3a_InterruptMask<true>\x26, _DiOS_TLS*, void**)\x0a"
"          at /divine/include/libc/include/sys/interrupt.h\x3a""77\x0a"
"      pthread_join at /divine/src/libc/functions/sys/pthread.cpp\x3a""539\x0a"
"      main at test/pthread/2.mutex-good.c\x3a""22\x0a"
"      _start at /divine/src/libc/functions/sys/start.cpp\x3a""76\x0a"
"    # backtrace 2\x3a\x0a"
"      __pthread_entry at /divine/src/libc/functions/sys/pthread.cpp\x3a""447\x0a"
"\x0a"
"Another command to gather data is \x60""call\x60, which allows you to call a function\x0a"
"defined in the program. The function must not take any parameters and will be\x0a"
"executed in *debug mode* (see \x5b\x40sec\x3a""debugmode\x5d -- the important caveat is that\x0a"
"any \x60""dbg.call\x60 instructions in your info function will be ignored). Execution\x0a"
"of the function will have no effect on the state of the simulated program. If\x0a"
"you have a program like this\x3a\x0a"
"\x0a"
"\x7e\x7e\x7e {.c}\x0a"
"#include <sys/divm.h>\x0a"
"\x0a"
"void print_hello()\x0a"
"{\x0a"
"    __vm_trace( _VM_T_Text, \x22hello world\x22 );\x0a"
"}\x0a"
"\x0a"
"int main() {}\x0a"
"\x7e\x7e\x7e\x0a"
"\x0a"
"The \x60""call\x60 command works like this\x3a\x0a"
"\x0a"
"    > call print_hello\x0a"
"      hello world\x0a"
"\x0a"
"Finally, the \x60info\x60 command serves as a universal information gathering alias\x0a"
"-- you can set up your own commands that then become available as \x60info\x60\x0a"
"sub-commands\x3a\x0a"
"\x0a"
"    > info --setup \x22""call print_hello\x22 hello\x0a"
"    > info hello\x0a"
"      hello world\x0a"
"\x0a"
"The \x60info\x60 command also provides a built-in sub-command \x60registers\x60 which\x0a"
"prints the current values of machine control registers (see also\x0a"
"\x5b\x40sec\x3a""control\x5d)\x3a\x0a"
"\x0a"
"    > info registers\x0a"
"    Constants\x3a    220000000\x0a"
"    Globals\x3a      120000000\x0a"
"    Frame\x3a        9cd2566220000000\x0a"
"    PC\x3a           340000000\x0a"
"    Scheduler\x3a    eb40000000\x0a"
"    State\x3a        4d7b876d20000000\x0a"
"    IntFrame\x3a     1020000000\x0a"
"    Flags\x3a        0\x0a"
"    FaultHandler\x3a b940000000\x0a"
"    ObjIdShuffle\x3a faa6693f\x0a"
"    User1\x3a        0\x0a"
"    User2\x3a        201879b120000000\x0a"
"    User3\x3a        6ca5bc2260000000\x0a"
"    User4\x3a        0\x0a"
"", 6348 ); }